tonalitytools.Mode
==================

.. inheritance-diagram:: abjad.tools.tonalitytools.Mode.Mode.Mode
   :private-bases:

.. autoclass:: abjad.tools.tonalitytools.Mode.Mode.Mode

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.Mode.Mode.Mode.melodic_diatonic_interval_segment

.. autoattribute:: abjad.tools.tonalitytools.Mode.Mode.Mode.mode_name

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__eq__

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__len__

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__ne__

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__repr__

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__str__
